
-- Draw Battery and percentage display
local function drawBattery(remaining, alarm_thresh, capacity, cell_count, gyro)
	local topbat = 40   -- original = 48
	local highbat = 100  -- original = 80
	local widebat = 50
	-- Battery
	lcd.drawFilledRectangle(148, topbat-7, 24, 7)	-- top of Battery
	lcd.drawRectangle(160-widebat/2-2, topbat-2, widebat+4, highbat+4)
	lcd.drawRectangle(160-widebat/2-1, topbat-1, widebat+2, highbat+2)
		
	-- Level of Battery
	local chgH = math.floor(remaining * highbat / 100)
	local chgY = highbat + topbat - chgH
	local chgHalarm = math.floor(alarm_thresh * highbat / 100)
	if chgH < chgHalarm then chgHalarm = chgH end
	local chgYalarm = highbat + topbat - chgHalarm
		
	lcd.setColor(0,220,0)
	lcd.drawFilledRectangle(160-widebat/2, chgY, widebat, chgH) --grün
	lcd.setColor(250,0,0)
	lcd.drawFilledRectangle(160-widebat/2, chgYalarm, widebat, chgHalarm) --rot
	lcd.setColor(0,0,0)
	
	-- Text in battery
	lcd.drawText(160-(lcd.getTextWidth(FONT_BIG, string.format("%s",capacity)) / 2),50, string.format("%s", capacity),FONT_BIG)
	lcd.drawText(145, 70, "mAh", FONT_NORMAL)
	local yCell = 120
	if gyro == 17 then yCell = 141 end
	lcd.drawText(160-(lcd.getTextWidth(FONT_NORMAL, string.format("%s S",cell_count)) / 2),yCell, string.format("%s S", cell_count),FONT_NORMAL)
	
	
	-- Percentage Display
	if( remaining > alarm_thresh ) then	
		lcd.drawRectangle(160-widebat/2-2, 2, widebat+4, 26, 5)
		lcd.drawRectangle(160-widebat/2-1, 3, widebat+2, 24, 4)
		lcd.drawText(160 - (lcd.getTextWidth(FONT_BIG, string.format("%.0f%%",remaining)) / 2),4, string.format("%.0f%%",
							remaining),FONT_BIG)
	else
		if( system.getTime() % 2 == 0 ) then -- blink every second
			lcd.drawRectangle(160-widebat/2-2, 2, widebat+4, 26, 5)
			lcd.drawRectangle(160-widebat/2-1, 3, widebat+2, 24, 4)
			lcd.drawText(160 - (lcd.getTextWidth(FONT_BIG, string.format("%.0f%%",remaining)) / 2),4, string.format("%.0f%%",
								remaining),FONT_BIG)
		end
	end

	collectgarbage()
end

-- Draw tank and percentage display
local function drawTank(remaining, alarm_thresh)
	local topbat = 38   -- original = 48
	local highbat = 118  -- original = 80
	local widebat = 26
	local midbat = 150
	local ox = 120
	local oy = 60
	local left = 168
	
	
	 -- gas station symbol
	-- lcd.drawRectangle(51+ox,31+oy,5,9)  
	-- lcd.drawLine(52+ox,34+oy,54+ox,34+oy)
	-- lcd.drawLine(50+ox,39+oy,56+ox,39+oy)
	-- lcd.drawLine(57+ox,31+oy,59+ox,33+oy)
	-- lcd.drawLine(59+ox,33+oy,59+ox,37+oy)
	-- lcd.drawPoint(58+ox,38+oy)  
	-- lcd.drawLine(57+ox,38+oy,57+ox,35+oy)  
	-- lcd.drawPoint(56+ox,35+oy)  
	lcd.setColor(0,220,0)
	lcd.drawText(52+ox,-17+oy, "F", FONT_BOLD)  
	lcd.setColor(250,0,0)
	lcd.drawText(52+ox,72+oy, "E", FONT_BOLD) 
	lcd.setColor(0,0,0)
	
	-- Tank
	lcd.drawFilledRectangle(midbat-widebat/2-2, topbat, 2, highbat+2)
	lcd.drawFilledRectangle(midbat + widebat/2, topbat, 2, highbat+2)
	lcd.drawFilledRectangle(midbat-widebat/2,topbat+highbat, widebat, 2)
	
	lcd.drawFilledRectangle(left, topbat, 17, 2)
	lcd.drawFilledRectangle(left, topbat + highbat, 17, 2)
	lcd.drawFilledRectangle(left, topbat + highbat/2, 14, 2)
	lcd.drawFilledRectangle(left, topbat + highbat/4, 12, 1)
	lcd.drawFilledRectangle(left, topbat + 3*highbat/4, 12, 1)
	
		
	-- Level of fuel
	local chgH = math.floor(remaining * highbat / 100)
	local chgY = highbat + topbat - chgH
	local chgHalarm = math.floor(alarm_thresh * highbat / 100)
	if chgH < chgHalarm then chgHalarm = chgH end
	local chgYalarm = highbat + topbat - chgHalarm
		
	lcd.setColor(0,220,0)
	lcd.drawFilledRectangle(midbat-widebat/2, chgY, widebat, chgH) --grün
	lcd.setColor(250,0,0)
	lcd.drawFilledRectangle(midbat-widebat/2, chgYalarm, widebat, chgHalarm) --rot
	lcd.setColor(0,0,0)
	
	
	--lcd.drawText(160-(lcd.getTextWidth(FONT_NORMAL, string.format("%s S",cell_count)) / 2),141, string.format("%s S", cell_count),FONT_NORMAL)
	
	
	-- Percentage Display
	if( remaining > alarm_thresh ) then	
		lcd.drawRectangle(160-25-2, 4, 50+4, 28, 5)
		lcd.drawRectangle(160-25-1, 5, 50+2, 26, 4)
		lcd.drawText(160 - (lcd.getTextWidth(FONT_BIG, string.format("%.0f%%",remaining)) / 2),6, string.format("%.0f%%",
							remaining),FONT_BIG)
	else
		if( system.getTime() % 2 == 0 ) then -- blink every second
			lcd.drawRectangle(160-25-2, 4, 50+4, 28, 5)
			lcd.drawRectangle(160-25-1, 5, 50+2, 26, 4)
			lcd.drawText(160 - (lcd.getTextWidth(FONT_BIG, string.format("%.0f%%",remaining)) / 2),6, string.format("%.0f%%",
								remaining),FONT_BIG)
		end
	end

	collectgarbage()
end

-- Draw voltage per cell
local function drawVpC(iDraw, maxDraw, iSep, thick, lengthSep, x, yStart, trns, average, min, yDist, calc)    -- Flightpack Voltage
	local yDraw = 25  -- Höhe der Anzeige ohne Seperator
	if average >  -1 then
		y = yStart -3
		-- draw fixed Text
		lcd.drawText(x + 60 - (lcd.getTextWidth(FONT_MINI,trns.mainbat) / 2),y,trns.mainbat,FONT_MINI)  --x=57,y=1
		lcd.drawText(x, y + 18, "min:", FONT_MINI)
		--lcd.drawText(x + 51, y + 18, "V", FONT_MINI)
		lcd.drawText(x + 63, y + 18, "akt:", FONT_MINI)
		--lcd.drawText(x + 111, y + 18, "V", FONT_MINI)
		

		-- draw Values, average is average of last 1000 values
		local deci = "%.2f"
		if min >= 10.0 then deci = "%.1f" end
		lcd.drawText(x + 60 - lcd.getTextWidth(FONT_BIG, string.format(deci, min)),y + 10, string.format(deci, min), FONT_BIG)
		deci = "%.2f"
		if average >= 10.0 then deci = "%.1f" end
		lcd.drawText(x + 119 - lcd.getTextWidth(FONT_BIG, string.format(deci, average)),y + 10, string.format(deci, average), FONT_BIG)
		iDraw = iDraw + 1
		if iDraw < maxDraw then
			lcd.drawFilledRectangle(x, yStart + yDraw + yDist, lengthSep, thick)
			if calc == true then iSep = iSep + 2 end
			return yStart + yDraw + yDist * 2 + thick, iDraw, iSep
		end		
		return yStart + yDraw, iDraw, iSep   -- letztes Feld, kein Seperator
	else
		return yStart, iDraw, iSep
	end	
end



-- Draw Rotor speed box
local function drawrpmbox(iDraw, maxDraw, iSep, thick, lengthSep, x, yStart, trns, rpm, min, max, yDist, calc)	-- Rotor Speed RPM
	local yDraw = 36  -- Höhe der Anzeige ohne Seperator
	if rpm > -1 then
		y = yStart - 9
		-- draw fixed Text
		-- lcd.drawText(x + 62 - (lcd.getTextWidth(FONT_MINI,trns.rotspeed) / 2),y,trns.rotspeed,FONT_MINI)
		-- lcd.drawText(x + 2, y, "r", FONT_MINI)
		-- lcd.drawText(x + 2, y + 10, "p", FONT_MINI)
		-- lcd.drawText(x, y + 20, "m", FONT_MINI)
		lcd.drawText(x + 112, y + 12, "-1", FONT_MINI)
		--lcd.drawLine (x + 100, y + 21, x + 119, y + 21)
		lcd.drawText(x + 100, y + 21, "min", FONT_MINI)
		lcd.drawText(x + 00, y + 35, "Max:", FONT_MINI)

		-- draw Values
		lcd.drawText(x + 97 - lcd.getTextWidth(FONT_MAXI,string.format("%.0f",rpm)),y,string.format("%.0f",rpm),FONT_MAXI)
		lcd.drawText(x + 95 - lcd.getTextWidth(FONT_MINI,string.format("%.0f",max)),y + 35, string.format("%.0f", max), FONT_MINI)
		iDraw = iDraw + 1
		if iDraw < maxDraw then
			lcd.drawFilledRectangle(x, yStart + yDraw + yDist, lengthSep, thick)
			if calc == true then iSep = iSep + 2 end
			return yStart + yDraw + yDist * 2 + thick, iDraw, iSep
		end		
		return yStart + yDraw, iDraw, iSep   -- letztes Feld, kein Seperator
	else
		return yStart, iDraw, iSep
	end	
end

-- Draw current box
local function drawCurrent(iDraw, maxDraw, iSep, thick, lengthSep, x, yStart, current, maxcur, yDist, calc) -- current
	local yDraw = 15  -- Höhe der Anzeige ohne Seperator
	if current > -1 then
		y = yStart - 5
		-- draw fixed Text
		lcd.drawText(x, y, "I", FONT_BIG)
		lcd.drawText(x + 7, y + 8, "Motor:", FONT_MINI)
		lcd.drawText(x + 86, y + 8, "A", FONT_MINI)
		lcd.drawText(x + 96, y, "max:", FONT_MINI)
			
		-- draw current 
		local deci = "%.1f"
		if current >= 100 then deci = "%.0f" end
		lcd.drawText(x + 85 - lcd.getTextWidth(FONT_BIG, string.format(deci,current)),y, string.format(deci,current),FONT_BIG)
		lcd.drawText(x + 110 - lcd.getTextWidth(FONT_MINI, string.format("%.0f A",maxcur)) / 2,y + 10, string.format("%.0fA",maxcur),FONT_MINI)
		iDraw = iDraw + 1
		if iDraw < maxDraw then
			lcd.drawFilledRectangle(x, yStart + yDraw + yDist, lengthSep, thick)
			if calc == true then iSep = iSep + 2 end
			return yStart + yDraw + yDist * 2 + thick, iDraw, iSep
		end		
		return yStart + yDraw, iDraw, iSep   -- letztes Feld, kein Seperator
	else
		return yStart, iDraw, iSep
	end	
end

-- Draw Receiver values
local function drawRxValues(iDraw, maxDraw, iSep, thick, lengthSep, x, yStart, colorRed, mina1, a1, mina2, a2, minrx_percent, rx_percent, minvoltage, voltage, yDist, calc)	-- Rx Values
	local yDraw = 28  -- Höhe der Anzeige ohne Seperator
	y = yStart - 2
	local linedist = 10
	local x1, x2 = 75, 108
	
	-- draw fixed Text
	lcd.drawText(x + 14, y , "min:", FONT_MINI) 
	lcd.drawText(x, y + linedist, "URx:", FONT_MINI) 
	lcd.drawText(x + 17, y + linedist *2, "akt:", FONT_MINI) 
	
	lcd.drawText(x + 61, y + 3, "V", FONT_MINI)
	lcd.drawText(x + 61, y + 20, "V", FONT_MINI)
	lcd.drawText(x + x1, y, "Q:", FONT_MINI) 
	lcd.drawText(x + x1, y + linedist, "A1:", FONT_MINI)
	lcd.drawText(x + x1, y + linedist*2, "A2:", FONT_MINI)
	
	

	-- draw RX Values
	if mina1 == 99 then mina1 = 0 end
	if mina2 == 99 then mina2 = 0 end
	if minrx_percent == 101.0 then minrx_percent = 0 end
	if minvoltage == 9.9 then minvoltage = 0 end
	
	-- Spannung:
	
	if minvoltage < 4.6 then lcd.setColor(colorRed,0,0) end
	lcd.drawText(x + 60 - lcd.getTextWidth(FONT_BOLD, string.format("%.1f",minvoltage)),y - 2, string.format("%.1f",minvoltage),FONT_BOLD)
	lcd.setColor(0,0,0)
	lcd.drawText(x + 60 - lcd.getTextWidth(FONT_BOLD, string.format("%.1f",voltage)), y + 15, string.format("%.1f",voltage),FONT_BOLD)
	
	-- Empfangsqualität:
	if minrx_percent < 100 then lcd.setColor(colorRed,0,0) end
	lcd.drawText(x + x2 - lcd.getTextWidth(FONT_MINI, string.format("%.0f/",minrx_percent)),y, string.format("%.0f/",minrx_percent),FONT_MINI) --rx_percent
	lcd.setColor(0,0,0)
	lcd.drawText(x + x2, y, string.format("%.0f",rx_percent),FONT_MINI)
	if mina1 < 10 then lcd.setColor(colorRed,0,0) end
	lcd.drawText(x + x2 - lcd.getTextWidth(FONT_MINI, string.format("%d/",mina1)),y + linedist, string.format("%d/",mina1),FONT_MINI)--x=98-
	lcd.setColor(0,0,0)
	lcd.drawText(x + x2, y + linedist, string.format("%d",a1),FONT_MINI)
	if mina2 < 10 then lcd.setColor(colorRed,0,0) end
	lcd.drawText(x + x2 - lcd.getTextWidth(FONT_MINI, string.format("%d/",mina2)),y + linedist*2, string.format("%d/",mina2),FONT_MINI)
	lcd.setColor(0,0,0)
	lcd.drawText(x + x2, y + linedist*2, string.format("%d",a2),FONT_MINI)
	iDraw = iDraw + 1
	if iDraw < maxDraw then
		lcd.drawFilledRectangle(x, yStart + yDraw + yDist, lengthSep, thick)
		if calc == true then iSep = iSep + 2 end
		return yStart + yDraw + yDist * 2 + thick, iDraw, iSep
	end		
	return yStart + yDraw, iDraw, iSep   -- letztes Feld, kein Seperator
end

-- Draw Total time box
local function drawTotalCount(iDraw, maxDraw, iSep, thick, lengthSep, x, yStart, trns, totalCount, totalFlighttime, yDist, calc) --Total flight Time
	local yDraw = 7  -- Höhe der Anzeige ohne Seperator
	y = yStart - 3
	-- draw fixed Text
	lcd.drawText(x, y, trns.ftime, FONT_MINI)
	
	-- draw Values
	lcd.drawText(x + 34,y, string.format("%.0f", totalCount), FONT_MINI) -- Anzahl Flüge gesamt
	
	std = math.floor(totalFlighttime / 3600)
	min = math.floor(totalFlighttime / 60) - (std * 60)
	sec = totalFlighttime - std * 3600 - min * 60
	lcd.drawText(x + 122 - lcd.getTextWidth(FONT_MINI, string.format("%0dh %02d' %02d\"", std, min, sec)), y, string.format("%0dh %02d' %02d\"",std, min, sec), FONT_MINI) -- total Flight time
	iDraw = iDraw + 1
	if iDraw < maxDraw then
		lcd.drawFilledRectangle(x, yStart + yDraw + yDist, lengthSep, thick)
		if calc == true then iSep = iSep + 2 end
		return yStart + yDraw + yDist * 2 + thick, iDraw, iSep
	end		
	return yStart + yDraw, iDraw, iSep   -- letztes Feld, kein Seperator
end

-- Draw Flight time box
local function drawFlightTime(iDraw, maxDraw, iSep, thick, lengthSep, x, yStart, trns, todayCount, flightTime, yDist, calc)	-- Flight flight Time
	local yDraw = 13  -- Höhe der Anzeige ohne Seperator
	y = yStart - 4
	local std, min, sec = 0, 0, 0

	-- draw Values
	lcd.drawText(x + 25 - lcd.getTextWidth(FONT_BIG, string.format("%.0f.", todayCount)),y, string.format("%.0f.", todayCount), FONT_BIG) -- flights today
	std = math.floor(flightTime / 3600000)
	min = math.floor(flightTime / 60000) - (std * 60000)
	sec = (flightTime % 60000) / 1000	
	if std ~= 0 then
		lcd.drawText(x + 125 - lcd.getTextWidth(FONT_BIG, string.format("%0dh %02d' %02d\"", std, min, sec)), y, string.format("%0dh %02d' %02d\"",std, min, sec), FONT_BIG) -- Flight time
	else
		lcd.drawText(x + 125 - lcd.getTextWidth(FONT_BIG, string.format("%02d' %02d\"",min, sec)), y, string.format("%02d' %02d\"",min, sec), FONT_BIG) -- Flight time
	end
	iDraw = iDraw + 1
	if iDraw < maxDraw then
		lcd.drawFilledRectangle(x, yStart + yDraw + yDist, lengthSep, thick)
		if calc == true then iSep = iSep + 2 end
		return yStart + yDraw + yDist * 2 + thick, iDraw, iSep
	end		
	return yStart + yDraw, iDraw, iSep   -- letztes Feld, kein Seperator
end

-- Draw engine time box
local function drawEngineTime(iDraw, maxDraw, iSep, thick, lengthSep, x, yStart, trns, engineTime, yDist, calc)	-- engine Time
	local yDraw = 11  -- Höhe der Anzeige ohne Seperator
	y = yStart - 4
	local std, min, sec = 0, 0, 0
	-- draw fixed Text
	lcd.drawText(x, y + 3, trns.engineTime, FONT_MINI)

	-- draw Values
	std = math.floor(engineTime / 3600000)
	min = math.floor(engineTime / 60000) - (std * 60000)
	sec = (engineTime % 60000) / 1000	
	if std ~= 0 then
		lcd.drawText(x + 122 - lcd.getTextWidth(FONT_NORMAL, string.format("%0dh %02d' %02d\"", std, min, sec)), y, string.format("%0dh %02d' %02d\"",std, min, sec), FONT_NORMAL) -- engine time
	else
		lcd.drawText(x + 122 - lcd.getTextWidth(FONT_NORMAL, string.format("%02d' %02d\"", min, sec)), y, string.format("%02d' %02d\"", min, sec), FONT_NORMAL) -- engine time
	end
	--lcd.drawText(255, 32, string.format("%02d.%02d.%02d", day.day, day.mon, day.year), FONT_MINI)
	iDraw = iDraw + 1
	if iDraw < maxDraw then
		lcd.drawFilledRectangle(x, yStart + yDraw + yDist, lengthSep, thick)
		if calc == true then iSep = iSep + 2 end
		return yStart + yDraw + yDist * 2 + thick, iDraw, iSep
	end		
	return yStart + yDraw, iDraw, iSep   -- letztes Feld, kein Seperator
end

--- Used Capacity
local function drawUsedCapacity(iDraw, maxDraw, iSep, thick, lengthSep, x, yStart, trns, used, initial_percent_used, capacity, yDist, calc )	-- Used Capacity
	local yDraw = 33  -- Höhe der Anzeige ohne Seperator
	if used > -1 then
		y = yStart - 4
    
		local total_used_capacity = math.ceil( used + (initial_percent_used * capacity) / 100 )

		-- draw fixed Text
		lcd.drawText(x + 60 - (lcd.getTextWidth(FONT_MINI,trns.usedCapa) / 2),y,trns.usedCapa,FONT_MINI)
		lcd.drawText(x + 96, y + 20, "mAh", FONT_MINI)
		--lcd.drawText(205, 97, trns.capacity, FONT_MINI)

		-- draw Values
		lcd.drawText(x + 94 - lcd.getTextWidth(FONT_MAXI, string.format("%.0f",total_used_capacity)),y + 5, string.format("%.0f",
					total_used_capacity), FONT_MAXI)
		--lcd.drawText(258,97, string.format("%s mAh", capacity),FONT_MINI)
		iDraw = iDraw + 1
		if iDraw < maxDraw then
			lcd.drawFilledRectangle(x, yStart + yDraw + yDist, lengthSep, thick)
			if calc == true then iSep = iSep + 2 end
			return yStart + yDraw + yDist * 2 + thick, iDraw, iSep
		end		
		return yStart + yDraw, iDraw, iSep   -- letztes Feld, kein Seperator
	else
		return yStart, iDraw, iSep
	end	
end

-- Draw Temperature
local function drawTempbox(iDraw, maxDraw, iSep, thick, lengthSep, x, yStart, temp, mintmp, maxtmp, trns, yDist, calc)	-- Temperature
	local yDraw = 15  -- Höhe der Anzeige ohne Seperator
	if temp > -100 then
		y = yStart - 5
		-- draw fixed Text
		lcd.drawText(x, y + 5, trns.temp, FONT_MINI)
		lcd.drawText(x + 80, y + 8,"°C",FONT_MINI)
		lcd.drawText(x + 96, y, "max:", FONT_MINI)

		-- draw Values  
		lcd.drawText(x + 78 - lcd.getTextWidth(FONT_BIG, string.format("%.0f",temp)),y, string.format("%.0f",temp),FONT_BIG)
		lcd.drawText(x + 110 - lcd.getTextWidth(FONT_MINI, string.format("%.0f°C",maxtmp)) / 2,y + 10, string.format("%.0f°C",maxtmp),FONT_MINI)
		iDraw = iDraw + 1
		if iDraw < maxDraw then
			lcd.drawFilledRectangle(x, yStart + yDraw + yDist, lengthSep, thick)
			if calc == true then iSep = iSep + 2 end
			return yStart + yDraw + yDist * 2 + thick, iDraw, iSep
		end		
		return yStart + yDraw, iDraw, iSep   -- letztes Feld, kein Seperator
	else
		return yStart, iDraw, iSep
	end		
end

-- Draw Status
local function drawStatusbox(iDraw, maxDraw, iSep, thick, lengthSep, x, yStart, status, yDist, calc)	-- Status
	local yDraw = 12  -- Höhe der Anzeige ohne Seperator
	if status ~= "" then
		y = yStart - 4
		-- draw Values  
		lcd.drawText(x + lengthSep/2 - lcd.getTextWidth(FONT_BOLD, status)/2,y, status,FONT_BOLD)
		iDraw = iDraw + 1
		if iDraw < maxDraw then
			lcd.drawFilledRectangle(x, yStart + yDraw + yDist, lengthSep, thick)
			if calc == true then iSep = iSep + 2 end
			return yStart + yDraw + yDist * 2 + thick, iDraw, iSep
		end		
		return yStart + yDraw, iDraw, iSep   -- letztes Feld, kein Seperator
	else
		return yStart, iDraw, iSep
	end		
end

-- Draw Pump voltage
local function drawPump_voltagebox(iDraw, maxDraw, iSep, thick, lengthSep, x, yStart, pump_voltage, minpump_voltage, maxpump_voltage, trns, yDist, calc)	-- Pump voltage
	local yDraw = 15  -- Höhe der Anzeige ohne Seperator
	if pump_voltage > -1 then
		y = yStart - 5
		-- draw fixed Text
		lcd.drawText(x, y + 5, "U Pump:", FONT_MINI)
		lcd.drawText(x + 80, y + 8,"V",FONT_MINI)
		lcd.drawText(x + 96, y, "min:", FONT_MINI)

		-- draw Values  
		lcd.drawText(x + 78 - lcd.getTextWidth(FONT_BIG, string.format("%.1f",pump_voltage)),y, string.format("%.1f",pump_voltage),FONT_BIG)
		lcd.drawText(x + 110 - lcd.getTextWidth(FONT_MINI, string.format("%.1fV",minpump_voltage)) / 2,y + 10, string.format("%.1fV",minpump_voltage),FONT_MINI)
		iDraw = iDraw + 1
		if iDraw < maxDraw then
			lcd.drawFilledRectangle(x, yStart + yDraw + yDist, lengthSep, thick)
			if calc == true then iSep = iSep + 2 end
			return yStart + yDraw + yDist * 2 + thick, iDraw, iSep
		end		
		return yStart + yDraw, iDraw, iSep   -- letztes Feld, kein Seperator
	else
		return yStart, iDraw, iSep
	end		
end

-- Draw PWM
local function drawPWMbox(iDraw, maxDraw, iSep, thick, lengthSep, x, yStart, PWM_percentage, minpwm, maxpwm, yDist, calc)	-- PWM
	local yDraw = 15  -- Höhe der Anzeige ohne Seperator
    if PWM_percentage > -1 then
		y = yStart - 5
		-- draw fixed Text
		lcd.drawText(x, y + 5, "PWM:", FONT_MINI)
		lcd.drawText(x + 80, y + 8,"%",FONT_MINI)
		lcd.drawText(x + 96, y, "max:", FONT_MINI)

		-- draw Values  
		lcd.drawText(x + 78 - lcd.getTextWidth(FONT_BIG, string.format("%.0f",PWM_percentage)),y, string.format("%.0f",PWM_percentage),FONT_BIG)
		lcd.drawText(x + 110 - lcd.getTextWidth(FONT_MINI, string.format("%.0f%%",maxpwm)) / 2,y + 10, string.format("%.0f%%",maxpwm),FONT_MINI)
		iDraw = iDraw + 1
		if iDraw < maxDraw then
			lcd.drawFilledRectangle(x, yStart + yDraw + yDist, lengthSep, thick)
			if calc == true then iSep = iSep + 2 end
			return yStart + yDraw + yDist * 2 + thick, iDraw, iSep
		end		
		return yStart + yDraw, iDraw, iSep   -- letztes Feld, kein Seperator
	else
		return yStart, iDraw, iSep
	end		
end

-- Draw Throttle
local function drawThrottlebox(iDraw, maxDraw, iSep, thick, lengthSep, x, yStart, throttle, minThrottle, maxThrottle, yDist, calc)	-- Throttle
	local yDraw = 15  -- Höhe der Anzeige ohne Seperator
	if throttle > -1 then
		y = yStart - 5
		-- draw fixed Text
		lcd.drawText(x, y + 5, "Throttle:", FONT_MINI)
		lcd.drawText(x + 80, y + 8,"%",FONT_MINI)
		lcd.drawText(x + 96, y, "max:", FONT_MINI)

		-- draw Values  
		lcd.drawText(x + 78 - lcd.getTextWidth(FONT_BIG, string.format("%.0f",throttle)),y, string.format("%.0f",throttle),FONT_BIG)
		lcd.drawText(x + 110 - lcd.getTextWidth(FONT_MINI, string.format("%.0f%%",maxThrottle)) / 2,y + 10, string.format("%.0f%%",maxThrottle),FONT_MINI)
		iDraw = iDraw + 1
		if iDraw < maxDraw then
			lcd.drawFilledRectangle(x, yStart + yDraw + yDist, lengthSep, thick)
			if calc == true then iSep = iSep + 2 end
			return yStart + yDraw + yDist * 2 + thick, iDraw, iSep
		end		
		return yStart + yDraw, iDraw, iSep   -- letztes Feld, kein Seperator
	else
		return yStart, iDraw, iSep
	end		
end

-- Draw Ibec
local function drawIBECbox(iDraw, maxDraw, iSep, thick, lengthSep, x, yStart, IBEC, minIBEC, maxIBEC, yDist, calc)	-- Ibec
	local yDraw = 15  -- Höhe der Anzeige ohne Seperator
	if IBEC > -1 then
		y = yStart - 5
		-- draw fixed Text
		lcd.drawText(x, y + 5, "IBEC:", FONT_MINI)
		lcd.drawText(x + 80, y + 8,"A",FONT_MINI)
		lcd.drawText(x + 96, y, "max:", FONT_MINI)

		-- draw Values  
		lcd.drawText(x + 78 - lcd.getTextWidth(FONT_BIG, string.format("%.0f",IBEC)),y, string.format("%.0f",IBEC),FONT_BIG)
		lcd.drawText(x + 110 - lcd.getTextWidth(FONT_MINI, string.format("%.0fA",maxIBEC)) / 2,y + 10, string.format("%.0fA",maxIBEC),FONT_MINI)
		iDraw = iDraw + 1
		if iDraw < maxDraw then
			lcd.drawFilledRectangle(x, yStart + yDraw + yDist, lengthSep, thick)
			if calc == true then iSep = iSep + 2 end
			return yStart + yDraw + yDist * 2 + thick, iDraw, iSep
		end		
		return yStart + yDraw, iDraw, iSep   -- letztes Feld, kein Seperator
	else
		return yStart, iDraw, iSep
	end	
end


-- Draw Gyro
local function drawMibotbox(gyro)
	  
	--[[
	Gyro Gain    
	Mini-Vstabi range is: +40 ... +120
	this range correponds to a
	Gyro Channel Value (times 100) range: -39 ... +93
	Scale and offset
	- renorm to zero ( gyro_channel * 100 + 39 )
	- scale ( 120 - 40 ) / ( 93 + 39 ) = 0.60606060...
	- offset +40
	- gyro_percent = (gyro_channel * 100 + 39) * 0.6060 + 40
	- gyro_percent = gyro_channel * 60.606 + 63.6363   
	--]]
	local gyro_percent = gyro * 60.606 + 63.6363

	if (gyro_percent < 40) then gyro_percent = 40 end
	if (gyro_percent > 120) then gyro_percent = 120 end

	-- draw fixed Text
	lcd.drawText(136,146,"GY",FONT_MINI)
	-- draw Max Values
	lcd.drawText(184 - lcd.getTextWidth(FONT_BIG, string.format("%.0f", gyro_percent)), 141, string.format("%.0f", gyro_percent), FONT_BIG)
	
end	


return {
	drawSeperator = drawSeperator,
	drawBattery = drawBattery,
	drawrpmbox = drawrpmbox,
	drawCurrent = drawCurrent,
	drawTotalCount = drawTotalCount,
	drawFlightTime = drawFlightTime,
	drawEngineTime = drawEngineTime,
	drawUsedCapacity = drawUsedCapacity,
	drawTempbox = drawTempbox,
	drawMibotbox = drawMibotbox,
	drawRxValues = drawRxValues,
	drawVpC = drawVpC,
	drawTempbox = drawTempbox,
	drawPWMbox = drawPWMbox,
	drawThrottlebox = drawThrottlebox,
	drawIBECbox = drawIBECbox,
	drawPump_voltagebox = drawPump_voltagebox,
	drawStatusbox = drawStatusbox,
	drawTank = drawTank
	
}




-- Draw left top box
-- local function drawLetopbox(trns, average, min, max)    -- Flightpack Voltage
	-- -- draw fixed Text
	-- lcd.drawText(57 - (lcd.getTextWidth(FONT_MINI,trns.mainbat) / 2),1,trns.mainbat,FONT_MINI)
	-- lcd.drawText(82, 20, "V", FONT_MINI)
	-- lcd.drawText(6, 32, "Min/Max:", FONT_MINI)

	-- -- draw Values, average is average of last 1000 values
	-- lcd.drawText(80 - lcd.getTextWidth(FONT_BIG, string.format("%.1f", average)),13, string.format("%.1f",
	-- average), FONT_BIG)
	-- lcd.drawText(60, 32, string.format("%.1f - %.1f", min, max), FONT_MINI)
-- end